@@ -4,24 +4,15 @@ import logging
 from ckan.lib.base import BaseController, c, render, request
 from . import dbutil
 
-import ckan.logic as logic
 import hashlib
 from . import plugin
-from pylons import config
 
 from paste.util.multidict import MultiDict
 
 from ckan.controllers.api import ApiController
 
-from ckan.exceptions import CkanVersionException
 import ckan.plugins.toolkit as tk
-
-try:
-    tk.requires_ckan_version("2.9")
-except CkanVersionException:
-    pass
-else:
-    from builtins import str
+from ckanext.googleanalytics import utils
 
 
 log = logging.getLogger("ckanext.googleanalytics")
@@ -39,25 +30,24 @@ class GAApiController(ApiController):
     def _post_analytics(
         self, user, request_obj_type, request_function, request_id
     ):
-        if config.get("googleanalytics.id"):
-            data_dict = {
-                "v": 1,
-                "tid": config.get("googleanalytics.id"),
-                "cid": hashlib.md5(user).hexdigest(),
-                # customer id should be obfuscated
-                "t": "event",
-                "dh": c.environ["HTTP_HOST"],
-                "dp": c.environ["PATH_INFO"],
-                "dr": c.environ.get("HTTP_REFERER", ""),
-                "ec": "CKAN API Request",
-                "ea": request_obj_type + request_function,
-                "el": request_id,
-            }
-            plugin.GoogleAnalyticsPlugin.analytics_queue.put(data_dict)
+        data_dict = {
+            "v": 1,
+            "tid": utils.config_id(),
+            "cid": hashlib.md5(user).hexdigest(),
+            # customer id should be obfuscated
+            "t": "event",
+            "dh": c.environ["HTTP_HOST"],
+            "dp": c.environ["PATH_INFO"],
+            "dr": c.environ.get("HTTP_REFERER", ""),
+            "ec": "CKAN API Request",
+            "ea": request_obj_type + request_function,
+            "el": request_id,
+        }
+        plugin.GoogleAnalyticsPlugin.analytics_queue.put(data_dict)
 
     def action(self, logic_function, ver=None):
         try:
-            function = logic.get_action(logic_function)
+            function = tk.get_action(logic_function)
             side_effect_free = getattr(function, "side_effect_free", False)
             request_data = self._get_request_data(
                 try_url_params=side_effect_free
